##  Quality Seal States of New Fact Sheets
The quality seal state of the newly created fact sheet is determined by how the quality seal states are enabled by admins. To learn more, see [Enabling or Disabling the Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD#loio275bf80d7a4410148ac1c4fbce489213__enabling_or_disabling_the_quality_seal).
Here is a summary of possible configurations and their impacts:
Quality Seal State - Broken | Quality Seal State - Draft | New Fact Sheet State
---|---|---
Enabled | Disabled | Broken (displayed as Check needed)
Enabled | Enabled | Draft
Disabled | Disabled | Approved
Disabled | Enabled | Draft


